@@ -254,25 +254,29 @@ class MainMenu(Navigable):
         elif new_filters == '::clear':
             self.filters = None
         else:
-            self.filters = new_filters
+            self.filters = new_filters.split(' ')
 
         self._update_menu_title()
 
         self._binary_wrapper.invalidate_data()
 
     def _update_menu_title(self):
-        report = (self.report + '; ') if self.report else ''
+        context = f'Context: {self.context}; ' if (self.context and self.context != 'none') else ''
 
-        filters = (self.filters + '; ') if self.filters else ''
+        report = f'Report: {self.report}; ' if self.report else ''
+
+        filters = f'Filter: {" ".join(self.filters)}; ' if self.filters else ''
 
         if len(self._data_provider.lines) > 1:
             task_count = self._data_provider.lines[-2]
         else:
             task_count = 'no tasks'
 
-        console.set_terminal_title('iTask: {}{}{}'.format(report, filters, task_count))
+        title_line = f'{context}{report}{filters}{task_count}'
 
-        self.main_menu.title = '{}{}{}'.format(report, filters, task_count)
+        console.set_terminal_title(f'iTask: {title_line}')
+
+        self.main_menu.title = f'{title_line}'
 
     def task_del(self):
         menu = Menu("Are you sure you want to remove ids '{}'?".format(str(self._get_selected_ids())), redraw=False,
@@ -383,12 +387,15 @@ class MainMenu(Navigable):
 
     def select_context(self):
         self._binary_wrapper.contexts()
-        new_context = input("Enter new context: [::cancel for cancel, none to unset]: ")
+        print()
+        print(f'Current context: {self.context}')
+        print()
+        new_context = input('Enter new context: [empty cancel, "none" to unset]: ')
 
-        if new_context == '::cancel':
+        if new_context == '':
             return
         else:
-            self._binary_wrapper.set_context(new_context)
+            self.context = new_context
 
         self._binary_wrapper.invalidate_data()
 
@@ -398,7 +405,7 @@ def parse_command_line():
 
     parser.add_argument("--task-data", help="Override TASKDATA environment variable")
 
-    parser.add_argument("-r", "--report", help="Initial report")
+    parser.add_argument("-r", "--report", default="next", help="Initial report")
 
     parser.add_argument("-f", "--filter", help="Initial filter")
 
